Documentation
¶
Index ¶
- Constants
- type AppModule
- type AppModuleBasic
- func (AppModuleBasic) ConsensusVersion() uint64
- func (AppModuleBasic) Name() string
- func (AppModuleBasic) RegisterGRPCGatewayRoutes(client.Context, *runtime.ServeMux)
- func (AppModuleBasic) RegisterInterfaces(codectypes.InterfaceRegistry)
- func (AppModuleBasic) RegisterLegacyAminoCodec(*codec.LegacyAmino)
- type ModuleInputs
- type ModuleOutputs
Constants ¶
const (
ConsensusVersion = 1
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppModule ¶
type AppModule struct {
AppModuleBasic
// contains filtered or unexported fields
}
AppModule implements the AppModule interface that defines the inter-dependent methods that modules need to implement.
func (AppModule) IsAppModule ¶
func (AppModule) IsAppModule()
IsAppModule implements the appmodule.AppModule interface.
func (AppModule) IsOnePerModuleType ¶
func (AppModule) IsOnePerModuleType()
IsOnePerModuleType implements the depinject.OnePerModuleType interface.
func (AppModule) RegisterServices ¶
func (AppModule) RegisterServices()
RegisterServices registers a gRPC query service to respond to the module-specific gRPC queries.
type AppModuleBasic ¶
type AppModuleBasic struct {
// contains filtered or unexported fields
}
AppModuleBasic implements the AppModuleBasic interface that defines the independent methods a Cosmos SDK module needs to implement.
func NewAppModuleBasic ¶
func NewAppModuleBasic(cdc codec.BinaryCodec) AppModuleBasic
func (AppModuleBasic) ConsensusVersion ¶
func (AppModuleBasic) ConsensusVersion() uint64
func (AppModuleBasic) Name ¶
func (AppModuleBasic) Name() string
Name returns the name of the module as a string.
func (AppModuleBasic) RegisterGRPCGatewayRoutes ¶
func (AppModuleBasic) RegisterGRPCGatewayRoutes(client.Context, *runtime.ServeMux)
RegisterGRPCGatewayRoutes registers the gRPC Gateway routes for the module.
func (AppModuleBasic) RegisterInterfaces ¶
func (AppModuleBasic) RegisterInterfaces(codectypes.InterfaceRegistry)
RegisterInterfaces registers a module's interface types and their concrete implementations as proto.Message.
func (AppModuleBasic) RegisterLegacyAminoCodec ¶
func (AppModuleBasic) RegisterLegacyAminoCodec(*codec.LegacyAmino)
RegisterLegacyAminoCodec registers the amino codec for the module, which is used to marshal and unmarshal structs to/from []byte in order to persist them in the module's KVStore.
type ModuleInputs ¶
type ModuleOutputs ¶
type ModuleOutputs struct {
depinject.Out
Module appmodule.AppModule
Keeper *keeper.Keeper
EVMEventProc evmengtypes.InjectedEventProc
}
func ProvideModule ¶
func ProvideModule(in ModuleInputs) (ModuleOutputs, error)