Documentation
¶
Index ¶
- Constants
- func InvokeProhibitStakingHooks(stakingHooks map[string]stakingtypes.StakingHooksWrapper) error
- type AppModule
- func (am AppModule) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
- func (am AppModule) EndBlock(ctx context.Context) ([]abci.ValidatorUpdate, error)
- func (am AppModule) ExportGenesis(ctx sdk.Context, cdc codec.JSONCodec) json.RawMessage
- func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, raw json.RawMessage) []abci.ValidatorUpdate
- func (AppModule) IsAppModule()
- func (AppModule) IsOnePerModuleType()
- func (am AppModule) RegisterServices(cfg module.Configurator)
- func (am AppModule) ValidateGenesis(cdc codec.JSONCodec, _ client.TxEncodingConfig, bz json.RawMessage) error
- type AppModuleBasic
- func (AppModuleBasic) ConsensusVersion() uint64
- func (AppModuleBasic) GetQueryCmd() *cobra.Command
- func (AppModuleBasic) Name() string
- func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx client.Context, mux *grpcruntime.ServeMux)
- func (AppModuleBasic) RegisterInterfaces(reg codectypes.InterfaceRegistry)
- func (AppModuleBasic) RegisterLegacyAminoCodec(*codec.LegacyAmino)
- type ModuleInputs
- type ModuleOutputs
Constants ¶
const (
ConsensusVersion = 1
)
Variables ¶
This section is empty.
Functions ¶
func InvokeProhibitStakingHooks ¶
func InvokeProhibitStakingHooks( stakingHooks map[string]stakingtypes.StakingHooksWrapper, ) error
InvokeProhibitStakingHooks is an invoker that prohibits the use of staking hooks. x/evmvalidator is compatible with x/staking partially, but it does not support staking hooks. So, other modules should not use staking hooks with x/evmvalidator.
Types ¶
type AppModule ¶
type AppModule struct {
AppModuleBasic
// contains filtered or unexported fields
}
AppModule implements the AppModule interface for the evmvalidator module.
func (AppModule) DefaultGenesis ¶
func (am AppModule) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
DefaultGenesis returns the evmvalidator module's default genesis state.
func (AppModule) ExportGenesis ¶
ExportGenesis returns the evmvalidator module's exported genesis state as raw JSON bytes.
func (AppModule) InitGenesis ¶
func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, raw json.RawMessage) []abci.ValidatorUpdate
InitGenesis performs the evmvalidator module's genesis initialization
func (AppModule) IsAppModule ¶
func (AppModule) IsAppModule()
IsAppModule implements the appmodule.AppModule interface.
func (AppModule) IsOnePerModuleType ¶
func (AppModule) IsOnePerModuleType()
IsOnePerModuleType implements the depinject.OnePerModuleType interface.
func (AppModule) RegisterServices ¶
func (am AppModule) RegisterServices(cfg module.Configurator)
RegisterServices registers a gRPC query service to respond to the module-specific gRPC queries.
func (AppModule) ValidateGenesis ¶
func (am AppModule) ValidateGenesis(cdc codec.JSONCodec, _ client.TxEncodingConfig, bz json.RawMessage) error
ValidateGenesis performs validation of the evmvalidator module's genesis state.
type AppModuleBasic ¶
type AppModuleBasic struct {
// contains filtered or unexported fields
}
AppModuleBasic implements the AppModuleBasic interface for the evmvalidator module.
func NewAppModuleBasic ¶
func NewAppModuleBasic(cdc codec.BinaryCodec) AppModuleBasic
func (AppModuleBasic) ConsensusVersion ¶
func (AppModuleBasic) ConsensusVersion() uint64
func (AppModuleBasic) GetQueryCmd ¶
func (AppModuleBasic) GetQueryCmd() *cobra.Command
GetQueryCmd returns the evmvalidator module's root query command.
func (AppModuleBasic) Name ¶
func (AppModuleBasic) Name() string
Name returns the evmvalidator module's name.
func (AppModuleBasic) RegisterGRPCGatewayRoutes ¶
func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx client.Context, mux *grpcruntime.ServeMux)
RegisterGRPCGatewayRoutes registers the gRPC Gateway routes for the module.
func (AppModuleBasic) RegisterInterfaces ¶
func (AppModuleBasic) RegisterInterfaces(reg codectypes.InterfaceRegistry)
RegisterInterfaces registers a module's interface types and their concrete implementations as proto.Message.
func (AppModuleBasic) RegisterLegacyAminoCodec ¶
func (AppModuleBasic) RegisterLegacyAminoCodec(*codec.LegacyAmino)
RegisterLegacyAminoCodec registers the amino codec for the module, which is used to marshal and unmarshal structs to/from []byte in order to persist them in the module's KVStore.
type ModuleInputs ¶
type ModuleInputs struct {
depinject.In
Config *modulev1.Module
Cdc codec.Codec
StoreKey *storetypes.KVStoreKey
ValidatorAddressCodec runtime.ValidatorAddressCodec
ConsensusAddressCodec runtime.ConsensusAddressCodec
}
type ModuleOutputs ¶
type ModuleOutputs struct {
depinject.Out
Module appmodule.AppModule
Keeper *keeper.Keeper
KeeperForEvidence *keeper.KeeperWrapperForEvidence
EVMEventProc evmengtypes.InjectedEventProc
}
func ProvideModule ¶
func ProvideModule(in ModuleInputs) (ModuleOutputs, error)